@@ -15,4 +15,10 @@
     
     #H2O AutoML
     make_automl()
-}
\ No newline at end of file
+}
+
+.onDetach <- function(libpath) {
+    
+    detach("package:h2o")
+
+}
